@@ -32,32 +32,4 @@ __PACKAGE__->config( name => 'MyAtom' );
 # Start the application
 __PACKAGE__->setup;
 
-
-=head1 NAME
-
-MyAtom - Catalyst based application
-
-=head1 SYNOPSIS
-
-    script/myatom_server.pl
-
-=head1 DESCRIPTION
-
-[enter your description here]
-
-=head1 SEE ALSO
-
-L<MyAtom::Controller::Root>, L<Catalyst>
-
-=head1 AUTHOR
-
-Takeru INOUE,,,
-
-=head1 LICENSE
-
-This library is free software, you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=cut
-
 1;
